@@ -78,13 +78,13 @@ class AnalysisForm(forms.Form):
     wasRepeated = forms.BooleanField(initial=False,required=False,label='Was repeated')
     wordDuration = forms.BooleanField(initial=True,required=False,label='Word duration')
     segmentalDurations = forms.BooleanField(initial=True,required=False,label='Segmental duration')
-    category = forms.CharField(label='Category source')
+    category = forms.CharField(blank=True,label='Category source')
     category.widget = forms.CheckboxSelectMultiple(choices=CAT_CHOICES)
     frequency = forms.BooleanField(initial=True,required=False,label='Frequency')
     nd = forms.BooleanField(initial=True,required=False,label='Neighbourhood density')
     phonotactic = forms.BooleanField(initial=True,required=False,label='Phonotactic probability')
-    lexical_scale = forms.CharField(label = 'Corpora to use for lexical statistics')
-    lexical_scale.widget = forms.CheckboxSelectMultiple(required=False,choices=LEX_SCALE_CHOICES)
+    lexical_scale = forms.CharField(blank=True,label = 'Corpora to use for lexical statistics')
+    lexical_scale.widget = forms.CheckboxSelectMultiple(choices=LEX_SCALE_CHOICES)
     additional_phono_stats = forms.BooleanField(initial=False,required=False,label='Additional phonological statistics')
     gender = forms.BooleanField(initial=True,required=False,label='Gender')
     age = forms.BooleanField(initial=True,required=False,label='Age')
